import urllib2
from pyquery import PyQuery
from datetime import datetime


def getfloat(number):
    number = number.translate(None, " ")
    return 0.0 if number == "" else float(number.split("*")[0])


def getsat(satellite):
    return satellite.translate(None, "-").lower()


def getmonth(month):
    month = month.split(' ')
    month = '%s %s' % (month[0][:3], month[1])
    return datetime.strptime(month, "%b %Y")


class CountsShift(object):
    sats = {'goes13': 32.0}

    def coefficient(self, sat, ch):
        return CountsShift.sats[sat]


class SpaceMeasurement(object):
    sats = {'goes13': 29.0}

    def coefficient(self, sat, ch):
        return SpaceMeasurement.sats[sat]


class PreLaunch(object):

    def __init__(self):
        table = self.table()
        self.coefficients = self.resume_coefficients(table)

    def table(self):
        page = urllib2.urlopen("http://www.star.nesdis.noaa.gov/smcd/spb/fwu/"
                               "homepage/GOES_Imager_Vis_PreCal.php")
        pq = PyQuery(page.read())
        return pq("table")[1].findall("tr")

    def resume_coefficients(self, table):
        co = {}
        for r in table[1:]:
            co[getsat(r[0].text_content())] = [getfloat(e.text_content())
                                               for e in r.getchildren()[1:]]
        return co

    def coefficient(self, sat, ch):
        return self.coefficients[getsat(sat)]


class PostLaunch(object):

    def __init__(self):
        table = self.table()
        self.sats = self.satellites(table)
        self.months = self.resume_coefficients(table)

    def table(self):
        page = urllib2.urlopen('http://www.star.nesdis.noaa.gov/smcd/spb/fwu/'
                               'homepage/GOES_Imager_Vis_OpCal.php')
        pq = PyQuery(page.read())
        return pq("table")[2].findall("tr")

    def satellites(self, table):
        sats = table[1:2]
        sats = [getsat(s.text_content()) for s in sats[0].getchildren()
                if not s.text_content() == ""]
        return sats

    def resume_coefficients(self, table):
        co = {}
        for r in table[2:]:
            co[getmonth(r[0].text_content())] = [getfloat(e.text_content())
                                                 for e in r.getchildren()[1:]]
        return co

    def get_month(self, dt):
        month = dt.month
        days = [datetime(dt.year, dt.month, d)
                    for d in range(1, dt.day + 1)]
        tuesdays = lambda d: d.weekday() == 1
        days = filter(tuesdays, days)
        date = datetime(dt.year, month, 1)
        if len(days) < 2 or date not in self.months:
            month -= 1
        date = datetime(dt.year, month, 1)
        return date

    def coefficient(self, dt, sat, ch):
        s = self.sats.index(sat)
        dt = self.get_month(dt)
        # TODO: Select the appropiate month according to the day of the month.
        return self.months[dt][s]

