from datetime import datetime
from netcdf import netcdf as nc
from channels.channel_01 import *


def calibration(date, satellite, channel=1):
    """
    Return the calibration parameters.

    Keyword arguments:
    satellite -- the name of the satellite.
    date --  the datetime of an image.
    """
    counts_shift = CountsShift()
    space_measurement = SpaceMeasurement()
    prelaunch = PreLaunch()
    postlaunch = PostLaunch()
    return {
        'counts_shift': counts_shift.coefficient(satellite, channel),
        'space_measurement': space_measurement.coefficient(satellite, channel),
        'prelaunch': prelaunch.coefficient(satellite, channel),
        'postlaunch': postlaunch.coefficient(date, satellite, channel)
    }


def calibration_to(filename):
    """
    Return the calibration parameters.

    Keyword arguments:
    filename -- the name of a netcdf file.
    """
    filename = filename.split('/')[-1]
    satellite = filename.split('.')[0]
    date = datetime.strptime(filename, 'goes13.%Y.%j.%H%M%S.BAND_01.nc')
    return calibration(date, satellite)


def calibrate(filename):
    """
    Append the calibration parameters as variables of the netcdf file.

    Keyword arguments:
    filename -- the name of a netcdf file.
    """
    params = calibration_to(filename)
    with nc.loader(filename) as root:
        for key, value in params.items():
            if isinstance(value, list):
                for i in range(len(value)):
                    nc.getvar(root, '%s_%i' % (key, i), 'f4', ('time', ))[:] = value[i]
            else:
                nc.getvar(root, key, 'f4', ('time', ))[:] = value
